@@ -16,7 +16,7 @@
 #' Formats can be specified as formatting strings, named vectors, user-defined
 #' formats, or vectorized formatting functions.  The \code{fdata} 
 #' function will
-#' apply the format to the associated column data using the \code{fapply} 
+#' apply the format to the associated column data using the \code{\link{fapply}} 
 #' function. A format can also be specified as a formatting list of the 
 #' previous four types.  See the \code{\link{fapply}}
 #' function for additional information.
@@ -25,11 +25,19 @@
 #' call the base R \code{\link{format}} function on 
 #' the data frame.  Any follow on parameters will be sent to the \code{format}
 #' function.   
+#' 
+#' The \code{fdata} function will also apply any \code{width} or \code{justify}
+#' attributes assigned to the data frame columns.  These attributes can be 
+#' controlled at the column level.  Using
+#' attributes to assign formatting and \code{fdata} to apply those attributes
+#' gives you a create deal of control over how
+#' your data is presented.
 #'
 #' @param x A data frame or tibble to be formatted.
 #' @param ... Any follow-on parameters to the format function.
 #' @return A new, formatted data frame or tibble with the formats applied.
-#' @seealso \code{\link{fapply}} to apply a format to a vector,
+#' @seealso \code{\link{fcat}} to create a format catalog, 
+#' \code{\link{fapply}} to apply a format to a vector,
 #' \code{\link{value}} to define a format object,
 #' \code{\link{fattr}} to assign formatting specifications to a single 
 #' column/vector, and the
@@ -39,61 +47,78 @@
 #' @import tibble
 #' @export
 #' @examples 
-#' ## Example 1: Simple Formats ##
-#' # Set up data frame
-#' df <- mtcars[1:10, c("mpg", "cyl")]
+#' # Construct data frame from state vectors
+#' df <- data.frame(state = state.abb, area = state.area)[1:10, ]
+#' 
+#' # Calculate percentages
+#' df$pct <- df$area / sum(state.area) * 100
+#' 
+#' # Before formatting 
 #' df
 #' 
-#' # Define and assign formats
-#' formats(df) <- list( mpg = value(condition(x >= 20, "High"),
-#'                                 condition(x < 20, "Low")),
-#'                      cyl = value(condition(x == 4, "Small"),
-#'                                 condition(x == 6, "Midsize"),
-#'                                 condition(x == 8, "Large")))
-#'               
-#' # Apply formatting
+#' #    state   area         pct
+#' # 1     AL  51609  1.42629378
+#' # 2     AK 589757 16.29883824
+#' # 3     AZ 113909  3.14804973
+#' # 4     AR  53104  1.46761040
+#' # 5     CA 158693  4.38572418
+#' # 6     CO 104247  2.88102556
+#' # 7     CT   5009  0.13843139
+#' # 8     DE   2057  0.05684835
+#' # 9     FL  58560  1.61839532
+#' # 10    GA  58876  1.62712846
+#' 
+#' # Create state name lookup list
+#' name_lookup <- state.name
+#' names(name_lookup) <- state.abb
+#' 
+#' # Assign formats
+#' formats(df) <- list(state = name_lookup,                         
+#'                     area  = function(x) format(x, big.mark = ","), 
+#'                     pct   = "%.1f%%") 
+#' 
+#' # Apply formats
 #' fdata(df)
 #' 
-#' ## Example 2: Formatting List ##
-#' # Set up data
-#' v1 <- c("num", "char", "date", "char", "date", "num")
-#' v2 <- list(1.258, "H", Sys.Date(),
-#'            "L", Sys.Date() + 60, 2.8865)
-#' 
-#' df <- data.frame(type = v1, values = I(v2))
-#' df
-#' 
-#' # Create formatting list
-#' lst <- flist(type = "row", lookup = v1, 
-#'              num = "%.1f",
-#'              char = value(condition(x == "H", "High"),
-#'                           condition(x == "L", "Low"),
-#'                           condition(TRUE, "NA")),
-#'              date = "%d%b%y")
-#' 
-#' # Assign list and lookup to column attributes
-#' df$values <- fattr(df$values, format = lst)
-#' 
-#' # Apply formatting list
-#' fdata(df)
+#' #          state    area   pct
+#' # 1      Alabama  51,609  1.4%
+#' # 2       Alaska 589,757 16.3%
+#' # 3      Arizona 113,909  3.1%
+#' # 4     Arkansas  53,104  1.5%
+#' # 5   California 158,693  4.4%
+#' # 6     Colorado 104,247  2.9%
+#' # 7  Connecticut   5,009  0.1%
+#' # 8     Delaware   2,057  0.1%
+#' # 9      Florida  58,560  1.6%
+#' # 10     Georgia  58,876  1.6%
 fdata <- function(x, ...) {
   
 
   if (all(class(x) != "data.frame"))
     stop("Input value must be derived from class data.frame")
   
+  # Apply formats to all columns
   ret <- list()
   for (nm in names(x)) {
   
-    
     ret[[length(ret) + 1]] <- fapply(x[[nm]])
     
+    # Restore any labels
+    if (!is.null(attr(x[[nm]], "label")))
+      attr(ret[[length(ret)]], "label") <- attr(x[[nm]], "label")
   }
   
+  # Restore names, as they are sometimes messed up
   names(ret) <- names(x)
+  
+  # Convert list to data frame
   ret <- as.data.frame(ret)
+  
+  # Transfer any rownames to new data frame
   rownames(ret) <- rownames(x)
   
+  # Call base R format function
+  # Honestly regret adding this.  Too late now.
   if (any(class(x) == "data.frame") & ...length() > 0) {
     
     ret <- base::format.data.frame(ret, ...)
@@ -110,6 +135,7 @@ fdata <- function(x, ...) {
     
   }
   
+  # Restore attributes
   class(ret) <- class(x)
   mode(ret) <- mode(x)
   names(ret) <- names(x)
